@@ -49,40 +49,38 @@ LANGUAGES = {
     NL_CODE: {"name": "Dutch"},
     UK_CODE: {"name": "Ukrainian"},
     CV_CODE: {"name": "Chuvash"},
-
-    XX_CODE: {"name": "Unknown"}
+    XX_CODE: {"name": "Unknown"},
 }
 
 # pattern_ru_orig = re.compile(r'[a-zA-Z\(\)\[\]\/\<\>•\'\n]+')
-pattern_ru_orig = re.compile(r'[\/\<\>•\'\n]+')
-double_spaces = re.compile(r'[\s]{2,}')
-double_commas = re.compile(r'[,]{2,}')
-double_dash = re.compile(r'[-—]{2,}')
-german_quotes = re.compile(r'[»«“„]+')
-quotes = re.compile(r'[“”„‟]+')
+pattern_ru_orig = re.compile(r"[\/\<\>•\'\n]+")
+double_spaces = re.compile(r"[\s]{2,}")
+double_commas = re.compile(r"[,]{2,}")
+double_dash = re.compile(r"[-—]{2,}")
+german_quotes = re.compile(r"[»«“„]+")
+quotes = re.compile(r"[“”„‟]+")
 pattern_zh = re.compile(
-    r'[」「“”„‟\x1a⓪①②③④⑤⑥⑦⑧⑨⑩⑴⑵⑶⑷⑸⑹⑺⑻⑼⑽*а-яА-Я\(\)\[\]\s\n\/\-\:•＂＃＄％＆＇＊＋－／＜＝＞＠［＼］＾＿｀｛｜｝～｟｠｢｣､、〃》【】〔〕〖〗〘〙〜〟〰〾〿–—‘’‛‧﹏〉]+')
+    r"[」「“”„‟\x1a⓪①②③④⑤⑥⑦⑧⑨⑩⑴⑵⑶⑷⑸⑹⑺⑻⑼⑽*а-яА-Я\(\)\[\]\s\n\/\-\:•＂＃＄％＆＇＊＋－／＜＝＞＠［＼］＾＿｀｛｜｝～｟｠｢｣､、〃》【】〔〕〖〗〘〙〜〟〰〾〿–—‘’‛‧﹏〉]+"
+)
 pattern_zh_total = re.compile(
-    r'[」「“”„‟\x1a⓪①②③④⑤⑥⑦⑧⑨⑩⑴⑵⑶⑷⑸⑹⑺⑻⑼⑽*a-zA-Zа-яА-Я\(\)\[\]\s\n\/\-\:•＂＃＄％＆＇（）＊＋－／：；＜＝＞＠［＼］＾＿｀｛｜｝～｟｠｢｣､、〃》【】〔〕〖〗〘〙〜〟〰〾〿–—‘’‛‧﹏〉]+')
+    r"[」「“”„‟\x1a⓪①②③④⑤⑥⑦⑧⑨⑩⑴⑵⑶⑷⑸⑹⑺⑻⑼⑽*a-zA-Zа-яА-Я\(\)\[\]\s\n\/\-\:•＂＃＄％＆＇（）＊＋－／：；＜＝＞＠［＼］＾＿｀｛｜｝～｟｠｢｣､、〃》【】〔〕〖〗〘〙〜〟〰〾〿–—‘’‛‧﹏〉]+"
+)
 pattern_jp = re.compile(
-    r'[“”„‟\x1a⓪①②③④⑤⑥⑦⑧⑨⑩⑴⑵⑶⑷⑸⑹⑺⑻⑼⑽*a-zA-Zа-яА-Я\(\)\[\]\s\n\/\-\:•＂＃＄％＆＇（）＊＋－／：；＜＝＞＠［＼］＾＿｀｛｜｝～｟｠｢｣､、〃》【】〔〕〖〗〘〙〜〟〰〾〿–—‘’‛‧﹏〉]+')
-pat_comma = re.compile(r'[\.]+')
-first_numbers = re.compile(r'^[0-9,\.]+')
-last_punct = re.compile(r'[,\.]+$')
-multiple_spaces = re.compile(r'\s+')
-pattern_ru = re.compile(r'[a-zA-Z\.\(\)\[\]\/\-\:!?\<\>;•\"\'«»——,]+')
-pattern_ru_letters_only = re.compile(r'[^а-яА-Я\s]+')
-german_foo = '%@%'
-german_months = 'Januar|Jänner|Janner|Februar|März|Marz|April|Mai|Juni|Juli|August|September|Oktober|October|November|Dezember'
-german_dates = re.compile(rf'(\s)(\d{{1,2}})\.(\s+)({german_months})')
-german_bdates  = re.compile(rf'(\s)(\d{{1,2}}){german_foo}(\s+)({german_months})')
+    r"[“”„‟\x1a⓪①②③④⑤⑥⑦⑧⑨⑩⑴⑵⑶⑷⑸⑹⑺⑻⑼⑽*a-zA-Zа-яА-Я\(\)\[\]\s\n\/\-\:•＂＃＄％＆＇（）＊＋－／：；＜＝＞＠［＼］＾＿｀｛｜｝～｟｠｢｣､、〃》【】〔〕〖〗〘〙〜〟〰〾〿–—‘’‛‧﹏〉]+"
+)
+pat_comma = re.compile(r"[\.]+")
+first_numbers = re.compile(r"^[0-9,\.]+")
+last_punct = re.compile(r"[,\.]+$")
+multiple_spaces = re.compile(r"\s+")
+pattern_ru = re.compile(r"[a-zA-Z\.\(\)\[\]\/\-\:!?\<\>;•\"\'«»——,]+")
+pattern_ru_letters_only = re.compile(r"[^а-яА-Я\s]+")
+german_foo = "%@%"
+german_months = "Januar|Jänner|Janner|Februar|März|Marz|April|Mai|Juni|Juli|August|September|Oktober|October|November|Dezember"
+german_dates = re.compile(rf"(\s)(\d{{1,2}})\.(\s+)({german_months})")
+german_bdates = re.compile(rf"(\s)(\d{{1,2}}){german_foo}(\s+)({german_months})")
 
 
-DEFAULT_PREPROCESSING = [
-    (double_spaces, ' '),
-    (double_commas, ','),
-    (double_dash, '—')
-]
+DEFAULT_PREPROCESSING = [(double_spaces, " "), (double_commas, ","), (double_dash, "—")]
 
 
 def is_lang_code_valid(langcode):
@@ -97,24 +95,24 @@ def split_by_razdel(line):
 
 def split_zh(line):
     """Split line in Chinese"""
-    return list(re.findall(r'[^!?。！？\.\!\?]+[!?。！？\.\!\?]?', line, flags=re.U))
+    return list(re.findall(r"[^!?。！？\.\!\?]+[!?。！？\.\!\?]?", line, flags=re.U))
 
 
 def split_jp(line):
     """Split line in Japanese"""
-    res = list(re.findall(r'[^!?。！？\.\!\?]+[!?。！？\.\!\?]?', line, flags=re.U))
-    for i,x in enumerate(res):
-        if x and x[0] == '」':
-            res[i-1] = res[i-1] + '」'
+    res = list(re.findall(r"[^!?。！？\.\!\?]+[!?。！？\.\!\?]?", line, flags=re.U))
+    for i, x in enumerate(res):
+        if x and x[0] == "」":
+            res[i - 1] = res[i - 1] + "」"
             res[i] = res[i][1:]
     return res
 
 
 def after_fr(lines):
     """Get French orthography into account"""
-    for i,x in enumerate(lines):
-        if x and x[0] == '»':
-            lines[i-1] = lines[i-1] + ' »'
+    for i, x in enumerate(lines):
+        if x and x[0] == "»":
+            lines[i - 1] = lines[i - 1] + " »"
             lines[i] = lines[i][1:]
     return lines
 
@@ -136,12 +134,11 @@ def preprocess(line, re_list, splitter):
 
 def ensure_paragraph_splitting(lines):
     """Split line by the paragraph marks if splitter failed"""
-    line_endings = [preprocessor.PARAGRAPH_MARK +
-                    x for x in preprocessor.LINE_ENDINGS]
+    line_endings = [preprocessor.PARAGRAPH_MARK + x for x in preprocessor.LINE_ENDINGS]
     res = []
     for line in lines:
         ser = []
-        get_substrings(line, '', line_endings, ser)
+        get_substrings(line, "", line_endings, ser)
         res.extend(ser)
     return res
 
@@ -166,7 +163,9 @@ def split_by_sentences_wrapper(lines, langcode):
         if any(m in line for m in marks):
             # print("found mark", line)
             if acc:
-                sentences = ensure_paragraph_splitting(split_by_sentences(acc, langcode))
+                sentences = ensure_paragraph_splitting(
+                    split_by_sentences(acc, langcode)
+                )
                 res.extend(sentences)
                 acc = []
             res.append(line)
@@ -174,60 +173,52 @@ def split_by_sentences_wrapper(lines, langcode):
             acc.append(line)
     if acc:
         sentences = ensure_paragraph_splitting(split_by_sentences(acc, langcode))
-        res.extend(sentences)            
+        res.extend(sentences)
     return res
 
 
 def split_by_sentences(lines, langcode):
     """Split line by sentences using language specific rules"""
-    line = ' '.join(lines)
+    line = " ".join(lines)
     if langcode == RU_CODE:
-        sentences = preprocess(line, [
-            (pattern_ru_orig, ''),
-            *DEFAULT_PREPROCESSING
-        ],
-            split_by_razdel)
+        sentences = preprocess(
+            line, [(pattern_ru_orig, ""), *DEFAULT_PREPROCESSING], split_by_razdel
+        )
         return sentences
     if langcode == DE_CODE:
-        sentences = preprocess(line, [
-            (german_quotes, '"'),
-            ( german_dates, rf'\1\2{german_foo}\3\4' ),
-            *DEFAULT_PREPROCESSING
-        ],
-            split_by_razdel)
-        sentences = preprocess_raw(sentences, [
-            (german_bdates, r'\1\2.\3\4')
-        ])
+        sentences = preprocess(
+            line,
+            [
+                (german_quotes, '"'),
+                (german_dates, rf"\1\2{german_foo}\3\4"),
+                *DEFAULT_PREPROCESSING,
+            ],
+            split_by_razdel,
+        )
+        sentences = preprocess_raw(sentences, [(german_bdates, r"\1\2.\3\4")])
         return sentences
     if langcode == ZH_CODE:
-        sentences = preprocess(line, [
-            # (pat_comma, '。'),
-            (pattern_zh, '')
-        ],
-            split_zh)
+        sentences = preprocess(
+            line,
+            [
+                # (pat_comma, '。'),
+                (pattern_zh, "")
+            ],
+            split_zh,
+        )
         return sentences
     if langcode == JP_CODE:
-        sentences = preprocess(line, [
-            (pat_comma, '。'),
-            (pattern_jp, '')
-        ],
-            split_jp)
-        return sentences    
+        sentences = preprocess(line, [(pat_comma, "。"), (pattern_jp, "")], split_jp)
+        return sentences
     if langcode == FR_CODE:
-        sentences = preprocess(line, [
-            *DEFAULT_PREPROCESSING
-        ],
-            split_by_razdel)
+        sentences = preprocess(line, [*DEFAULT_PREPROCESSING], split_by_razdel)
         sentences = after_fr(sentences)
         return sentences
 
     # apply default splitting
-    sentences = preprocess(line, [
-        *DEFAULT_PREPROCESSING
-    ],
-        split_by_razdel)
+    sentences = preprocess(line, [*DEFAULT_PREPROCESSING], split_by_razdel)
 
-    if sentences[-1].strip() == '':
+    if sentences[-1].strip() == "":
         return sentences[:-1]
 
     return sentences
@@ -235,16 +226,15 @@ def split_by_sentences(lines, langcode):
 
 def split_by_sentences_and_save(raw_path, splitted_path, langcode, handle_marks=False):
     """Split raw text file by sentences and save"""
-    with open(raw_path, mode='r', encoding='utf-8') as input_file, open(splitted_path, mode='w', encoding='utf-8') as out_file:
+    with open(raw_path, mode="r", encoding="utf-8") as input_file, open(
+        splitted_path, mode="w", encoding="utf-8"
+    ) as out_file:
         if is_lang_code_valid(langcode):
             lines = input_file.readlines()
-            lines = preprocess_raw(lines, [
-                (quotes, '"')
-            ])
+            lines = preprocess_raw(lines, [(quotes, '"')])
             if handle_marks:
-                lines = preprocessor.mark_paragraphs(lines)  
-                sentences = split_by_sentences_wrapper(
-                    lines, langcode)
+                lines = preprocessor.mark_paragraphs(lines)
+                sentences = split_by_sentences_wrapper(lines, langcode)
             else:
                 sentences = split_by_sentences(lines, langcode)
         else:
